:mod:`nolearn.console`
----------------------

.. warning::

   The nolearn.console module will be removed in nolearn 0.6.  If you
   want to continue using this module, please consider copying the
   code into your own project.  And take a look at alternatives like
   the click library.

.. automodule:: nolearn.console

  .. autoclass:: Command
